@@ -39,7 +39,7 @@ func (ClusterRole) Render(o interface{}, ns string, r *Row) error {
 	r.Fields = Fields{
 		cr.Name,
 		mapToStr(cr.Labels),
-		toAge(cr.ObjectMeta.CreationTimestamp),
+		toAge(cr.GetCreationTimestamp()),
 	}
 
 	return nil
