@@ -113,7 +113,7 @@ func (t *mockModel) SetLabelFilter(string)              {}
 func (t *mockModel) Empty() bool                        { return false }
 func (t *mockModel) Count() int                         { return 1 }
 func (t *mockModel) HasMetrics() bool                   { return true }
-func (t *mockModel) Peek() render.TableData             { return makeTableData() }
+func (t *mockModel) Peek() *render.TableData            { return makeTableData() }
 func (t *mockModel) ClusterWide() bool                  { return false }
 func (t *mockModel) GetNamespace() string               { return "blee" }
 func (t *mockModel) SetNamespace(string)                {}
@@ -141,8 +141,8 @@ func (t *mockModel) ToYAML(ctx context.Context, path string) (string, error) {
 func (t *mockModel) InNamespace(string) bool      { return true }
 func (t *mockModel) SetRefreshRate(time.Duration) {}
 
-func makeTableData() render.TableData {
-	return render.TableData{
+func makeTableData() *render.TableData {
+	return &render.TableData{
 		Namespace: client.ClusterScope,
 		Header: render.Header{
 			render.HeaderColumn{Name: "RESOURCE"},
