@@ -6,7 +6,6 @@ import (
 	"github.com/derailed/k9s/internal"
 	"github.com/derailed/k9s/internal/client"
 	"github.com/derailed/k9s/internal/model"
-	"github.com/derailed/k9s/internal/render"
 	"github.com/derailed/k9s/internal/ui"
 	"github.com/gdamore/tcell/v2"
 	"github.com/rs/zerolog/log"
@@ -24,7 +23,6 @@ func NewHelm(gvr client.GVR) ResourceViewer {
 	c := Helm{
 		ResourceViewer: NewBrowser(gvr),
 	}
-	c.GetTable().SetColorerFn(render.Helm{}.ColorerFunc())
 	c.GetTable().SetBorderFocusColor(tcell.ColorMediumSpringGreen)
 	c.GetTable().SetSelectedStyle(tcell.StyleDefault.Foreground(tcell.ColorWhite).Background(tcell.ColorMediumSpringGreen).Attributes(tcell.AttrNone))
 	c.AddBindKeysFn(c.bindKeys)
