@@ -58,10 +58,6 @@ func NewLog(gvr client.GVR, opts *dao.LogOptions) *Log {
 	return &l
 }
 
-func logChan() dao.LogChan {
-	return make(dao.LogChan, 2)
-}
-
 // Init initializes the viewer.
 func (l *Log) Init(ctx context.Context) (err error) {
 	if l.app, err = extractApp(ctx); err != nil {
@@ -350,7 +346,6 @@ func (l *Log) Flush(lines [][]byte) {
 		if l.cancelUpdates {
 			break
 		}
-		log.Debug().Msgf("FLUSH %q", string(lines[i]))
 		_, _ = l.ansiWriter.Write(lines[i])
 	}
 	if l.follow {
