@@ -5,7 +5,6 @@ import (
 
 	"github.com/derailed/k9s/internal/client"
 	"github.com/derailed/k9s/internal/dao"
-	"github.com/derailed/k9s/internal/render"
 	"github.com/derailed/k9s/internal/ui"
 	"github.com/derailed/tview"
 	"github.com/gdamore/tcell/v2"
@@ -23,7 +22,6 @@ func NewReplicaSet(gvr client.GVR) ResourceViewer {
 	}
 	r.AddBindKeysFn(r.bindKeys)
 	r.GetTable().SetEnterFn(r.showPods)
-	r.GetTable().SetColorerFn(render.ReplicaSet{}.ColorerFunc())
 
 	return &r
 }
